/// <reference types="node" />
import { ChildProcess } from 'child_process';
import colors from 'kleur';
import { Stream } from 'stream';
export interface ProcessEnv {
    [key: string]: string | undefined;
}
declare type StdioOptions = 'pipe' | 'ignore' | 'inherit' | Array<('pipe' | 'ipc' | 'ignore' | 'inherit' | Stream | number | null | undefined)>;
declare type StdioNull = 'inherit' | 'ignore' | Stream;
declare type StdioPipe = undefined | null | 'pipe';
declare type StdioPipeOrNull = StdioNull | StdioPipe;
export declare type TStdIO = StdioOptions | [StdioPipeOrNull, StdioPipeOrNull, StdioPipeOrNull];
export declare type TextPredicate = (text: string, next: TextPredicate) => boolean;
export declare type ErrorSearch = (text: string, next: ErrorSearch) => string | void | null | false;
export interface IRunOptions {
    env?: ProcessEnv;
    timeout?: number;
    notAutoKill?: boolean;
    stdio?: TStdIO;
    shell?: boolean;
    prepareProcess?: (proc: ChildProcess) => void;
}
export interface IGlobalConfig {
    logFilter?: TextPredicate;
    stdOutIsError?: ErrorSearch;
    stdErrIsError?: TextPredicate;
}
export declare function getColorPrefix(colorFunc: any): any;
export declare function createColorRegexp(colors: colors.Color[]): RegExp;
export declare function removeColor(message: any): any;
export declare function getGlobalConfig(): IGlobalConfig;
export declare function setGlobalConfig(config: IGlobalConfig): void;
export declare function run(command: any, { env, timeout, notAutoKill, stdio, shell, prepareProcess, }?: IRunOptions): Promise<void>;
export declare function singleProcess(func: any): (...args: any[]) => Promise<any>;
export declare function singleCall(func: any): (...args: any[]) => any;
export {};
